# coding: utf-8

"""
    aind-dataverse-service

     ## aind-dataverse-service  Service to pull data from Allen Institute's Dataverse database.  

    The version of the OpenAPI document: 0.0.3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from aind_dataverse_service_client.api.default_api import DefaultApi


class TestDefaultApi(unittest.TestCase):
    """DefaultApi unit test stubs"""

    def setUp(self) -> None:
        self.api = DefaultApi()

    def tearDown(self) -> None:
        pass

    def test_get_table(self) -> None:
        """Test case for get_table

        Get Table
        """
        pass

    def test_get_table_info(self) -> None:
        """Test case for get_table_info

        Get Table Info
        """
        pass


if __name__ == '__main__':
    unittest.main()
